#!/bin/sh
#------------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Counter Fraud Management PID 5725-P56
#
# (C) Copyright IBM Corp. 2018  All rights reserved.
#
# The source code for this program is not published or otherwise divested
# of its trade secrets, irrespective of what has been deposited with the
# U. S. Copyright Office.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#------------------------------------------------------------------------
#
# Watch the queue depth of an MQ queue until it becomes 0.
# Note: Run this script as the user 'mqm'
# e.g. su -c "cfm_mq_queue_watch.sh '<Q_MGR>' '<QUEUE>' '<MQ_BIN_DIR>'" -s /bin/sh mqm
#

echo "TASK START DATE :" [`date +%H:%M:%S`]
SCRIPT_DIR=$(cd -P -- "$(dirname -- "$0")" && pwd -P)

# Input Variables
MQ_QUEUE_MGR=$1
MQ_QUEUE=$2
MQ_INSTALL_DIR=$3
SLEEP_TIMER=$4

# Set defaults if not set
[[ "${MQ_QUEUE_MGR}" = "" ]]     	&& MQ_QUEUE_MGR="CFQM"
[[ "${MQ_QUEUE}" = "" ]]          && MQ_QUEUE="CF.IDENTITY.INSIGHTS"
[[ "${MQ_INSTALL_DIR}" = "" ]]    && MQ_INSTALL_DIR="/opt/mqm/bin"
[[ "${SLEEP_TIMER}" = "" ]]       && SLEEP_TIMER="15m"

# Debug to Display Variables
echo [`date +%H:%M:%S`] "******************************************************"
echo [`date +%H:%M:%S`] "DEBUG: MQ Queue Manager         : ${MQ_QUEUE_MGR}"
echo [`date +%H:%M:%S`] "DEBUG: MQ Queue                 : ${MQ_QUEUE}"
echo [`date +%H:%M:%S`] "DEBUG: MQ Install Dir           : ${MQ_INSTALL_DIR}"
echo [`date +%H:%M:%S`] "DEBUG: Sleep Timer              : ${SLEEP_TIMER}"
echo [`date +%H:%M:%S`] "******************************************************"

# Set aliases
alias log.info='echo [INFO][`date +%H:%M:%S`] ${STEP} - '
alias log.error='echo [ERROR][`date +%H:%M:%S`] ${STEP} - '
alias log.warn='echo [WARNING][`date +%H:%M:%S`] ${STEP} - '

typeset -i rc="-1"

STEP="Watching $MQ_QUEUE on $MQ_QUEUE_MGR"

while [ $rc -ne "0" ]
do

  # Check the Queue Depth for messages
  mqsc_output=$(echo "DISPLAY QLOCAL($MQ_QUEUE) CURDEPTH" | $MQ_INSTALL_DIR/runmqsc $MQ_QUEUE_MGR | grep 'CURDEPTH(')
  
  # Some error occurred
  if [ -z "$mqsc_output" ]; then
    log.error "Unable to obtain the queue depth."
    rc="-1"
    break
  fi

  # Parse the output from MQSC
  rc=$(echo "$mqsc_output" | sed 's/.*CURDEPTH//' | tr -d '()')

  # The queue is processing messages
  if [ $rc -gt "0" ]; then
    log.info "Queue depth is $rc"
    sleep $SLEEP_TIMER
  fi

  if [ $rc -eq "0" ]; then
    log.info "There are no messages on the queue ($rc)."
  fi

done

echo "TASK STOP DATE :" [`date +%H:%M:%S`]
exit $rc
